Calculate Normalized Graph Laplacian
NormLaplacian.RdCalculate Normalized graph laplacian of the input adjacency matrix, the graph laplacian L = I-D^(-1/2)AD^(-1/2), where D is a diagonal matrix with row sums of A as entries.
NormLaplacian.RdCalculate Normalized graph laplacian of the input adjacency matrix, the graph laplacian L = I-D^(-1/2)AD^(-1/2), where D is a diagonal matrix with row sums of A as entries.