Assign cluster to cells/genes
assign_clusters_GMM.RdBased on a probability cutoff genes/cells are assigned to all clusters for which they have a probability higher than 'cutoff'.
assign_clusters_GMM.RdBased on a probability cutoff genes/cells are assigned to all clusters for which they have a probability higher than 'cutoff'.