| cabinet-package | R Documentation |
A package created for a Cabinet Office Coffee & Coding session to demonstrate the usethis and devtools packages for creating your own package.
Maintainer: Matt Dray mwdray@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.