An S4 class that contains all elements needed for CA.
caclust-class.RdClass to store biclustering clustering results.
Slots
cell_clustersfactors. The assigned cell clusters with cell names in the names attribute.
gene_clustersfactors. The assigned gene clusters with gene names in the names attribute.
SNNsparse shared nearest neighbours matrix. Values indicate the jaccard similarity.
parametersList of used parameters and function name with which results were generated.
eigenmatrix, Slot for storing eigenvectors from spectral clustering
cell_probmatrix. Matrix that stores the probabilities that a cell belongs to a cluster. Only filled when running spectral clustering with GMM.
gene_probmatrix. Matrix that stores the probabilities that a gene belongs to a cluster. Only filled when running spectral clustering with GMM.
cell_idxsinteger. Indices of the cells in the SNN adjacency matrix.
gene_idxsinteger. Indices of the genes in the SNN adjacency matrix.
bimapdata.frame. Data frame storing the biMAP coordinates (x, y) and the type (cell or gene) as well as the assigned clusters.