Detecting eigengap.
eigengap.RdSearching for the largest gap between conjuncted eigenvalues which are sorted in an ascending order, the most important eigenvalues and eigenvectors are the ones before the detected eigengap.
eigengap.RdSearching for the largest gap between conjuncted eigenvalues which are sorted in an ascending order, the most important eigenvalues and eigenvectors are the ones before the detected eigengap.