Remove clusters only consisting of cells/genes
rm_monoclusters.RdTakes an object of class biclust and removes all clusters that only consist of cells or genes.
Usage
rm_monoclusters(obj, ...)
# S4 method for caclust
rm_monoclusters(obj)
# S4 method for Biclust
rm_monoclusters(obj)
# S4 method for SingleCellExperiment
rm_monoclusters(obj, subset_sce = FALSE)